diff mbox

kmod: Adjust kvm_smp_send_reschedule availability

Message ID 4A084624.4010704@siemens.com (mailing list archive)
State New, archived
Headers show

Commit Message

Jan Kiszka May 11, 2009, 3:37 p.m. UTC
Also x86_64 before 2.6.26 requires kvm_smp_send_reschedule.

Signed-off-by: Jan Kiszka <jan.kiszka@siemens.com>
---

 external-module-compat-comm.h |    6 ++++--
 external-module-compat.c      |    6 ++++--
 2 files changed, 8 insertions(+), 4 deletions(-)

--
To unsubscribe from this list: send the line "unsubscribe kvm" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
diff mbox

Patch

diff --git a/external-module-compat-comm.h b/external-module-compat-comm.h
index 88d2314..e1e203c 100644
--- a/external-module-compat-comm.h
+++ b/external-module-compat-comm.h
@@ -214,10 +214,12 @@  typedef _Bool bool;
 #endif
 
 /*
  * smp_call_function_mask() is not defined/exported below 2.6.24
  */
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24) || \
+    (defined CONFIG_X86_64 && LINUX_VERSION_CODE < KERNEL_VERSION(2,6,26))
 
 int kvm_smp_call_function_mask(cpumask_t mask, void (*func) (void *info),
 			       void *info, int wait);
@@ -214,10 +214,12 @@  typedef _Bool bool;
 
 /*
- * smp_call_function_mask() is not defined/exported below 2.6.24
+ * smp_call_function_mask() is not defined/exported below 2.6.24 on all
+ * targets and below 2.6.26 on x86-64
  */
 
diff --git a/external-module-compat.c b/external-module-compat.c
index ca269cc..f6013f3 100644
--- a/external-module-compat.c
+++ b/external-module-compat.c
@@ -138,10 +138,12 @@  uint64_t div64_u64(uint64_t dividend, uint64_t divisor)
 #endif
 
 /*
  * smp_call_function_mask() is not defined/exported below 2.6.24
  */
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,24) || \
+    (defined CONFIG_X86_64 && LINUX_VERSION_CODE < KERNEL_VERSION(2,6,26))
 
 #include <linux/smp.h>
@@ -138,10 +138,12 @@  uint64_t div64_u64(uint64_t dividend, uint64_t divisor)
 
 /*
- * smp_call_function_mask() is not defined/exported below 2.6.24
+ * smp_call_function_mask() is not defined/exported below 2.6.24 on all
+ * targets and below 2.6.26 on x86-64
  */
 